shithub: pokered

Download patch

ref: 00648063845ec1045e34410f6f5cf376ca0ea211
parent: bb76c06120bcd1fc0f86bd3cc96cbbde93c0c80c
author: SatoMew <SatoMew@users.noreply.github.com>
date: Tue Dec 1 17:33:03 EST 2020

Fix outdated comments

--- a/data/tilesets/tileset_headers.asm
+++ b/data/tilesets/tileset_headers.asm
@@ -3,11 +3,11 @@
 	dw \1, \2, \3 ; Block, GFX, Coll
 	db \4, \5, \6 ; counter tiles
 	db \7         ; grass tile
-	db \8         ; permission (indoor, cave, outdoor)
+	db \8         ; animations (none, water, water & flowers)
 ENDM
 
 Tilesets:
 	; block, gfx, coll, 3 counter tiles, grass tile, permission
 	tileset Overworld_Block,   Overworld_GFX,   Overworld_Coll,   $FF,$FF,$FF, $52, TILEANIM_WATER_FLOWER
 	tileset RedsHouse1_Block,  RedsHouse1_GFX,  RedsHouse1_Coll,  $FF,$FF,$FF, $FF, TILEANIM_NONE
 	tileset Mart_Block,        Mart_GFX,        Mart_Coll,        $18,$19,$1E, $FF, TILEANIM_NONE
@@ -3,11 +3,11 @@
 
 Tilesets:
-	; block, gfx, coll, 3 counter tiles, grass tile, permission
+	; block, gfx, coll, 3 counter tiles, grass tile, animations
 	tileset Overworld_Block,   Overworld_GFX,   Overworld_Coll,   $FF,$FF,$FF, $52, TILEANIM_WATER_FLOWER
 	tileset RedsHouse1_Block,  RedsHouse1_GFX,  RedsHouse1_Coll,  $FF,$FF,$FF, $FF, TILEANIM_NONE